This template shows off a simple AI-Chat, which you can use to talk to OpenAI's
GPT series of models.

**This template requires an OpenAI API key to function.**

You can get your API key from [OpenAI's
website](https://platform.openai.com/api-keys). Make sure to enter your key into
the `__init__.py` file before trying to run the project.

The app has a single chat page, where you can type in a message and get a
response. If there aren't any messages yet, the bot displays a placeholder with
helfpul suggestions to the user. Once the first message is entered, it switches
to a conversation view.

A progress circle indicates to the user when the bot is busy generating a
response.
